from .spark import Spark

__version__ = '0.0.1'
__license__ = 'MIT'
__author__ = 'Kevin Walchko'
__doc__ = u"""
Draw bar graphs from input data. By default, it draws a vertical bar
chart, but you can also draw a horizontal bar chart if you want.
"""
